@@ -1,9 +1,13 @@
 `detrend` <-
     function(rwl, y.name = names(rwl), make.plot = FALSE,
              method=c("Spline", "ModNegExp", "Mean"),
-             nyrs = NULL, f = 0.5, pos.slope = FALSE)
+             nyrs = NULL, f = 0.5, pos.slope = FALSE,
+             constrain.modnegexp = c("never", "when.fail", "always"))
 {
+    stopifnot(identical(make.plot, TRUE) || identical(make.plot, FALSE),
+              identical(pos.slope, FALSE) || identical(pos.slope, TRUE))
     known.methods <- c("Spline", "ModNegExp", "Mean")
+    constrain2 <- match.arg(constrain.modnegexp)
     method2 <- match.arg(arg = method,
                          choices = known.methods,
                          several.ok = TRUE)
@@ -36,7 +40,9 @@
                                   fits <- detrend.series(rwl.i, make.plot=FALSE,
                                                          method=method2,
                                                          nyrs=nyrs, f=f,
-                                                         pos.slope=pos.slope)
+                                                         pos.slope=pos.slope,
+                                                         constrain.modnegexp=
+                                                         constrain2)
                                   if(is.data.frame(fits))
                                       row.names(fits) <- rn
                                   fits
@@ -47,7 +53,8 @@
             fits <- detrend.series(rwl[[i]], y.name=y.name[i],
                                    make.plot=make.plot,
                                    method=method2, nyrs=nyrs, f=f,
-                                   pos.slope=pos.slope)
+                                   pos.slope=pos.slope,
+                                   constrain.modnegexp=constrain2)
             if(is.data.frame(fits))
                 row.names(fits) <- rn
             out[[i]] <- fits
