@@ -1,11 +1,13 @@
 `detrend.series` <-
     function(y, y.name = "", make.plot = TRUE,
              method = c("Spline", "ModNegExp", "Mean"),
-             nyrs = NULL, f = 0.5, pos.slope = FALSE)
+             nyrs = NULL, f = 0.5, pos.slope = FALSE,
+             constrain.modnegexp = c("never", "when.fail", "always"))
 {
     stopifnot(identical(make.plot, TRUE) || identical(make.plot, FALSE),
               identical(pos.slope, FALSE) || identical(pos.slope, TRUE))
     known.methods <- c("Spline", "ModNegExp", "Mean")
+    constrain2 <- match.arg(constrain.modnegexp)
     method2 <- match.arg(arg = method,
                          choices = known.methods,
                          several.ok = TRUE)
@@ -17,6 +19,7 @@
         stop("'NA's are not allowed in the middle of the series")
     }
     y2 <- y[good.y]
+    nY2 <- length(y2)
     ## Recode any zero values to 0.001
     y2[y2 == 0] <- 0.001
 
@@ -24,28 +27,76 @@
 
     if("ModNegExp" %in% method2){
         ## Nec or lm
-        nec.func <- function(Y) {
-            a <- mean(Y[seq_len(floor(length(Y) * 0.1))])
+        nec.func <- function(Y, constrain) {
+            nY <- length(Y)
+            a <- mean(Y[seq_len(max(1, floor(nY * 0.1)))])
             b <- -0.01
-            k <- mean(Y[floor(length(Y) * 0.9):length(Y)])
-            nec <- nls(formula = Y ~ a * exp(b * seq_along(Y)) + k,
-                       start = list(a=a, b=b, k=k))
-            if(coef(nec)[2] >= 0) stop()
-            fits <- predict(nec)
-            if(fits[1] < fits[length(fits)]) stop()
-            if(fits[length(fits)] < 0) stop()
+            k <- mean(Y[floor(nY * 0.9):nY])
+            nlsForm <- Y ~ a * exp(b * seq_len(nY)) + k
+            nlsStart <- list(a=a, b=b, k=k)
+            checked <- FALSE
+            ## Note: nls() may signal an error
+            if (constrain == "never") {
+                nec <- nls(formula = nlsForm, start = nlsStart)
+            } else if (constrain == "always") {
+                nec <- nls(formula = nlsForm, start = nlsStart,
+                           lower = c(a=0, b=-Inf, k=0),
+                           upper = c(a=Inf, b=0, k=Inf),
+                           algorithm = "port")
+            } else {
+                nec <- nls(formula = nlsForm, start = nlsStart)
+                coefs <- coef(nec)
+                if (coefs[1] <= 0 || coefs[2] >= 0) {
+                    stop()
+                }
+                fits <- predict(nec)
+                if (fits[nY] > 0) {
+                    checked <- TRUE
+                } else {
+                    nec <- nls(formula = nlsForm, start = nlsStart,
+                               lower = c(a=0, b=-Inf, k=0),
+                               upper = c(a=Inf, b=0, k=Inf),
+                               algorithm = "port")
+                }
+            }
+            if (!checked) {
+                coefs <- coef(nec)
+                if (coefs[1] <= 0 || coefs[2] >= 0) {
+                    stop()
+                }
+                fits <- predict(nec)
+                if (fits[nY] <= 0) {
+                    ## This error is a special case that needs to be
+                    ## detected (if only for giving a warning).  Any
+                    ## smarter way to implement this?
+                    return(NULL)
+                }
+            }
             fits
         }
-        ModNegExp <- try(nec.func(y2), silent=TRUE)
-        if(class(ModNegExp)=="try-error") {
+        ModNegExp <- try(nec.func(y2, constrain2), silent=TRUE)
+        mneNotPositive <- is.null(ModNegExp)
+
+        if (mneNotPositive || class(ModNegExp) == "try-error") {
             ## Straight line via linear regression
-            tm <- cbind(1, seq_along(y2))
+            if (mneNotPositive) {
+                warning("Fits from ModNegExp are not all positive, see constrain.modnegexp argument in detrend.series")
+            }
+            tm <- cbind(1, seq_len(nY2))
             lm1 <- lm.fit(tm, y2)
             coefs <- lm1[["coefficients"]]
             if (all(is.finite(coefs)) && (coefs[2] <= 0 || pos.slope)) {
                 ModNegExp <- drop(tm %*% coefs)
+                useMean <- !isTRUE(ModNegExp[1] > 0 &&
+                                   ModNegExp[nY2] > 0)
+                if (useMean) {
+                    warning("Linear fit (backup of ModNegExp) is not all positive")
+                }
             } else {
-                ModNegExp <- rep(mean(y2), length(y2))
+                useMean <- TRUE
+            }
+            if (useMean) {
+                ModNegExp <- rep.int(mean(y2), nY2)
             }
         }
         resids$ModNegExp <- y2 / ModNegExp
@@ -60,10 +111,14 @@
         ## 50%, or 0.50, at a wavelength of 67%n years if nyrs and f
         ## are NULL
         if(is.null(nyrs))
-            nyrs2 <- floor(length(y2) * 0.67)
+            nyrs2 <- floor(nY2 * 0.67)
         else
             nyrs2 <- nyrs
-        Spline <- ffcsaps(y=y2, x=seq_along(y2), nyrs=nyrs2, f=f)
+        Spline <- ffcsaps(y=y2, x=seq_len(nY2), nyrs=nyrs2, f=f)
+        if (any(Spline <= 0)) {
+            warning("Spline fit is not all positive")
+            Spline <- rep.int(mean(y2), nY2)
+        }
         resids$Spline <- y2 / Spline
         do.spline <- TRUE
     } else {
@@ -72,7 +127,7 @@
 
     if("Mean" %in% method2){
         ## Fit a horiz line
-        Mean <- rep(mean(y2), length(y2))
+        Mean <- rep.int(mean(y2), nY2)
         resids$Mean <- y2 / Mean
         do.mean <- TRUE
     } else {
@@ -88,8 +143,8 @@
         n.rows <- 1 + ncol(resids)
         mat <- matrix(seq_len(n.rows), n.rows, 1)
         layout(mat,
-               widths=rep(0.5, ncol(mat)),
-               heights=rep(1, nrow(mat)))
+               widths=rep.int(0.5, ncol(mat)),
+               heights=rep.int(1, nrow(mat)))
 
         plot(y2, type="l", ylab="mm",
              xlab=gettext("Age (Yrs)", domain="R-dplR"),
@@ -135,6 +190,5 @@
     resids2 <- resids2[, method2]
     ## Make sure names (years) are included if there is only one method
     if(!is.data.frame(resids2)) names(resids2) <- names(y)
-
     resids2
 }
