@@ -1,15 +1,16 @@
 `seg.plot` <-
     function(rwl, ...)
 {
-    if(!is.data.frame(rwl))
+    if (!is.data.frame(rwl)) {
         stop("'rwl' must be a data.frame")
+    }
     yr <- as.numeric(row.names(rwl))
-    first.year <- apply(rwl, 2, yr.range, yr.vec=yr)[1, ]
+    first.year <- as.matrix(apply(rwl, 2, yr.range, yr.vec=yr))[1, ]
     neworder <- order(first.year, decreasing=FALSE)
     segs <- rwl[, neworder, drop=FALSE]
     n.col <- ncol(segs)
     seq.col <- seq_len(n.col)
-    for(i in seq.col){
+    for (i in seq.col) {
         segs[[i]][!is.na(segs[[i]])] <- i
     }
     op <- par(no.readonly=TRUE) # Save par
