@@ -1,3 +1,6 @@
+#ifndef DPLR_H
+#define DPLR_H
+
 #include <R.h>  /* to include Rconfig.h */
           
 #ifdef ENABLE_NLS
@@ -7,3 +10,5 @@
 #define _(String) (String)
 #define dngettext(pkg, String, StringP, N) (N > 1 ? StringP: String)
 #endif
+
+#endif
